@@ -2,7 +2,7 @@ package PAR::Dist;
 require Exporter;
 use vars qw/$VERSION @ISA @EXPORT/;
 
-$VERSION    = '0.15_01';
+$VERSION    = '0.15_02';
 @ISA	    = 'Exporter';
 @EXPORT	    = qw/
   blib_to_par
@@ -25,7 +25,9 @@ PAR::Dist - Create and manipulate PAR distributions
 
 =head1 VERSION
 
-This document describes version 0.15 of PAR::Dist, released Jul 25, 2006.
+This document describes version 0.15_02 of PAR::Dist, released Aug 8, 2006.
+
+This is a developer release intended for early adopters and testers!
 
 =head1 SYNOPSIS
 
